==> jc-1.4.0.tar.gz: jas/ConstAttr.h <==
// public class jas.ConstAttr

// class file dependencies
// @dep_class 7db643a4926f144a jas_ConstAttr
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_ConstAttr_H_
#define _JC_jas_ConstAttr_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_ConstAttr$sub_refs	_jc_jas_ConstAttr$sub_refs;
typedef struct _jc_jas_ConstAttr$sub_nonrefs	_jc_jas_ConstAttr$sub_nonrefs;
typedef struct _jc_jas_ConstAttr$refs	_jc_jas_ConstAttr$refs;
typedef struct _jc_jas_ConstAttr$nonrefs	_jc_jas_ConstAttr$nonrefs;
typedef struct _jc_jas_ConstAttr$object	_jc_jas_ConstAttr$object;

typedef struct _jc_jas_ConstAttr$fields_struct	_jc_jas_ConstAttr$fields_struct;
typedef const struct _jc_jas_ConstAttr$vmethods	_jc_jas_ConstAttr$vmethods;
typedef const struct _jc_jas_ConstAttr$vtable	_jc_jas_ConstAttr$vtable;
typedef const struct _jc_jas_ConstAttr$vtype	_jc_jas_ConstAttr$vtype;

// Class fields structure
struct _jc_jas_ConstAttr$fields_struct {
	struct _jc_jas_CP$object	*attr;
};
extern _jc_jas_ConstAttr$fields_struct _jc_jas_ConstAttr$class_fields;

// Constructors
extern void _jc_jas_ConstAttr$method$_init$24c6ba968508310b(_jc_env *, struct _jc_jas_ConstAttr$object *, struct _jc_jas_CP$object *);

// Virtual methods
extern void _jc_jas_ConstAttr$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_ConstAttr$object *, struct _jc_jas_ClassEnv$object *);
extern void _jc_jas_ConstAttr$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_ConstAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_ConstAttr$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_ConstAttr$method_info$write$c5719140f8114b75;

// Static methods
extern void _jc_jas_ConstAttr$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_jas_ConstAttr$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_ConstAttr$object *, struct _jc_jas_ClassEnv$object *);
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_ConstAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_ConstAttr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_ConstAttr$vmethods	jas_ConstAttr;
};

// Vtype
struct _jc_jas_ConstAttr$vtype {
	_jc_type			type;
	_jc_jas_ConstAttr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_ConstAttr$sub_refs {
	struct _jc_jas_CP$object	*val;
};

// Reference instance fields (object)
struct _jc_jas_ConstAttr$refs {
    _jc_jas_ConstAttr$sub_refs	jas_ConstAttr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_ConstAttr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_ConstAttr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_ConstAttr$sub_nonrefs	jas_ConstAttr;
};

// Object instance structure
struct _jc_jas_ConstAttr$object {
	_jc_jas_ConstAttr$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_ConstAttr$vtype	*vtype;
	_jc_jas_ConstAttr$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_ConstAttr$vtype _jc_jas_ConstAttr$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_ConstAttr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_ConstAttr$class_object;

#endif	/* _JC_jas_ConstAttr_H_ */

==> jc-1.4.6.tar.gz: jas/ConstAttr.h <==
// public class jas.ConstAttr

// class file dependencies
// @dep_class 7db643a4926f144a jas_ConstAttr
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_ConstAttr_H_
#define _JC_jas_ConstAttr_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_ConstAttr$sub_refs	_jc_jas_ConstAttr$sub_refs;
typedef struct _jc_jas_ConstAttr$sub_nonrefs	_jc_jas_ConstAttr$sub_nonrefs;
typedef struct _jc_jas_ConstAttr$refs	_jc_jas_ConstAttr$refs;
typedef struct _jc_jas_ConstAttr$nonrefs	_jc_jas_ConstAttr$nonrefs;
typedef struct _jc_jas_ConstAttr$object	_jc_jas_ConstAttr$object;

typedef struct _jc_jas_ConstAttr$fields_struct	_jc_jas_ConstAttr$fields_struct;
typedef const struct _jc_jas_ConstAttr$vmethods	_jc_jas_ConstAttr$vmethods;
typedef const struct _jc_jas_ConstAttr$vtable	_jc_jas_ConstAttr$vtable;
typedef const struct _jc_jas_ConstAttr$vtype	_jc_jas_ConstAttr$vtype;

// Class fields structure
struct _jc_jas_ConstAttr$fields_struct {
	struct _jc_jas_CP$object	*attr;
};
extern _jc_jas_ConstAttr$fields_struct _jc_jas_ConstAttr$class_fields;

// Constructors
extern void _jc_jas_ConstAttr$method$_init$24c6ba968508310b(_jc_env *, struct _jc_jas_ConstAttr$object *, struct _jc_jas_CP$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_ConstAttr$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_ConstAttr$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern void _jc_jas_ConstAttr$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_ConstAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_ConstAttr$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_ConstAttr$method_info$write$c5719140f8114b75;

// Static methods
extern void _jc_jas_ConstAttr$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_jas_ConstAttr$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_ConstAttr$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_ConstAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_ConstAttr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_ConstAttr$vmethods	jas_ConstAttr;
};

// Vtype
struct _jc_jas_ConstAttr$vtype {
	_jc_type			type;
	_jc_jas_ConstAttr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_ConstAttr$sub_refs {
	struct _jc_jas_CP$object	*val;
};

// Reference instance fields (object)
struct _jc_jas_ConstAttr$refs {
    _jc_jas_ConstAttr$sub_refs	jas_ConstAttr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_ConstAttr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_ConstAttr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_ConstAttr$sub_nonrefs	jas_ConstAttr;
};

// Object instance structure
struct _jc_jas_ConstAttr$object {
	_jc_jas_ConstAttr$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_ConstAttr$vtype	*vtype;
	_jc_jas_ConstAttr$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_ConstAttr$vtype _jc_jas_ConstAttr$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_ConstAttr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_ConstAttr$class_object;

#endif	/* _JC_jas_ConstAttr_H_ */
